// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KACCOUNTS_VERSION_H
#define KACCOUNTS_VERSION_H

#define KACCOUNTS_VERSION_STRING "26.07.90"
#define KACCOUNTS_VERSION_MAJOR 26
#define KACCOUNTS_VERSION_MINOR 7
#define KACCOUNTS_VERSION_PATCH 90
#define KACCOUNTS_VERSION ((26<<16)|(7<<8)|(90))

#endif
